import BN from "bn.js";
import { Keypair, LAMPORTS_PER_SOL } from "@solana/web3.js";
export const truthy = (value) => !!value;
export function toNumber(numberOrBn, mintOrDecimals) {
    if (BN.isBN(numberOrBn) || typeof numberOrBn == "bigint") {
        return amountAsNum(numberOrBn, mintOrDecimals);
    }
    else {
        return numberOrBn;
    }
}
export function amountAsNum(amount, mintOrDecimals) {
    const decimals = typeof mintOrDecimals === "number"
        ? mintOrDecimals
        : mintOrDecimals.decimals;
    const factor = new BN(Math.pow(10, decimals).toString());
    const decimal = new BN(amount.toString()).mod(factor).toNumber() / factor.toNumber();
    return new BN(amount.toString()).div(factor).toNumber() + decimal;
}
export function toBN(numberOrBn, mintOrDecimals) {
    const decimals = typeof mintOrDecimals === "number"
        ? mintOrDecimals
        : mintOrDecimals.decimals;
    if (BN.isBN(numberOrBn)) {
        return numberOrBn;
    }
    else {
        return new BN(Number(Math.floor(Number(numberOrBn))))
            .mul(new BN(Math.pow(10, decimals)))
            .add(new BN(Math.round((Number(numberOrBn) % 1) * Math.pow(10, decimals))));
    }
}
export function supplyAsNum(mint) {
    return amountAsNum(new BN(mint.supply.toString()), mint);
}
export function numberWithCommas(x, decimals = 4) {
    return roundToDecimals(x, decimals).toLocaleString("en-US", {
        maximumFractionDigits: decimals,
    });
}
export function roundToDecimals(num, decimals) {
    return Math.trunc(num * Math.pow(10, decimals)) / Math.pow(10, decimals);
}
export function humanReadableBigint(bigint, decimals, round = decimals) {
    return numberWithCommas(roundToDecimals(toNumber(bigint, decimals), round));
}
export function humanReadable(bn, decimalsOrMint) {
    return numberWithCommas(roundToDecimals(toNumber(bn, decimalsOrMint), typeof decimalsOrMint == "number"
        ? decimalsOrMint
        : decimalsOrMint.decimals));
}
export const getSolanaKeypair = (secretKey) => Keypair.fromSecretKey(Buffer.from(secretKey, "base64"));
export const airdrop = async (connection, to, amt) => {
    const txSig = await connection.requestAirdrop(to, amt * LAMPORTS_PER_SOL);
    while (true) {
        const tx = await connection.getTransaction(txSig, {
            commitment: 'confirmed'
        });
        if (tx) {
            break;
        }
        await new Promise(resolve => setTimeout(resolve, 100));
        console.log(`waiting on airdrop`);
    }
};
//# sourceMappingURL=utils.js.map