/// <reference types="node" />
import { AnchorProvider, Program, Provider } from "@coral-xyz/anchor";
import { Commitment, Connection, Finality, PublicKey, SendOptions, SignatureStatus, Signer, Transaction, TransactionInstruction, TransactionSignature } from "@solana/web3.js";
export interface InstructionResult<A> {
    instructions: TransactionInstruction[];
    signers: Signer[];
    output: A;
}
export interface BigInstructionResult<A> {
    instructions: TransactionInstruction[][];
    signers: Signer[][];
    output: A;
}
export declare function sendInstructions(provider: AnchorProvider, instructions: TransactionInstruction[], signers?: Signer[], payer?: PublicKey, commitment?: Commitment, idlErrors?: Map<number, string>): Promise<string>;
export declare function sendMultipleInstructions(provider: AnchorProvider, instructionGroups: TransactionInstruction[][], signerGroups: Signer[][], payer?: PublicKey, finality?: Finality, idlErrors?: Map<number, string>): Promise<Iterable<string>>;
export declare function execute<Output>(program: Program<any>, provider: AnchorProvider, command: InstructionResult<Output>, payer?: PublicKey, commitment?: Commitment): Promise<Output & {
    txid?: string;
}>;
export declare function executeBig<Output>(program: Program, provider: AnchorProvider, command: BigInstructionResult<Output>, payer?: PublicKey, finality?: Finality): Promise<Output & {
    txids?: string[];
}>;
export type PriorityLevel = 'NONE' | 'LOW' | 'MEDIUM' | 'HIGH' | 'VERY_HIGH';
export declare const sendMultipleInstructionsWithPrioFee: (provider: AnchorProvider, instructionGroups: TransactionInstruction[][], signerGroups: Signer[][], payer?: PublicKey, priorityLevel?: PriorityLevel, finality?: Finality, timeout?: number, idlErrors?: Map<number, string>) => Promise<Iterable<string>>;
export declare const awaitTransactionSignatureConfirmation: (txid: TransactionSignature, timeout: number, connection: Connection, commitment?: Commitment, queryStatus?: boolean) => Promise<SignatureStatus | null | void>;
export declare function sendAndConfirmWithRetry(connection: Connection, txn: Buffer, sendOptions: SendOptions, commitment: Commitment, timeout?: number): Promise<{
    txid: string;
}>;
export declare function stringToTransaction(solanaTransaction: string): Transaction;
export declare function bufferToTransaction(solanaTransaction: Buffer): Transaction;
type Status = {
    totalProgress: number;
    currentBatchProgress: number;
    currentBatchSize: number;
};
export declare function bulkSendTransactions(provider: Provider, txs: Transaction[], onProgress?: (status: Status) => void, triesRemaining?: number): Promise<string[]>;
export declare function bulkSendRawTransactions(connection: Connection, txs: Buffer[], onProgress?: (status: Status) => void, lastValidBlockHeight?: number, skipPreflight?: boolean): Promise<string[]>;
export {};
//# sourceMappingURL=transaction.d.ts.map